@@ -1,29 +1,21 @@
 # -*- coding: utf-8 -*-
-import fuclib
-import sys
-import os
+# Author: Eamonn
+# Email: china.eamonn@gmail.com
+# Link: https://elanpy.com
 
-from scrapy_rabbit.Lib.project import get_project_settings
-from scrapy_rabbit.settings import overridden_settings
-#
-# try:
-#     sys.path.append(os.path.abspath('../..'))
-#     import settings
-# except ModuleNotFoundError:
-#     sys.path.append(os.path.abspath('..'))
-#     import settings
-from sys import exit
+import fuclib
+import os
 import scrapy
-from scrapy_rabbit.Lib.getConfig import get_config
+from scrapy_rabbit.conf import conf
 from scrapy.utils.reqser import request_to_dict
 from collections import Generator
 from asyncio.events import new_event_loop
 from asyncio.tasks import run_coroutine_threadsafe
 from logging import getLogger
 from threading import Thread
-from scrapy_rabbit.Lib.http import Request
-from scrapy_rabbit.Lib.mongodb import MongoDBConnect
-from scrapy_rabbit.Lib.rabbit import RabbitConnect
+from scrapy_rabbit.http import Request
+from scrapy_rabbit.utils import get_project_settings
+from scrapy_rabbit.rabbitmq import RabbitConnect
 from re import search
 from pickle import dumps, loads
 from pika import exceptions
@@ -31,12 +23,15 @@ from asyncio import set_event_loop
 from time import ctime
 from functools import partial
 from traceback import print_exc
-from scrapy_rabbit.Lib.http import random_ua
+from scrapy_rabbit.http import random_ua
+from scrapy_rabbit.settings import overridden_settings
+import sys
+
+sys.path.append(os.path.abspath('../..'))
+sys.path.append(os.path.abspath('../../..'))
 
 logger = getLogger(__name__)
 
-config = get_config()
-
 
 class DaemonRun(Thread):
     def __init__(self, func, loop, scrapy_object, *args, **kwargs):
@@ -63,11 +58,10 @@ class Engine(object):
     proxy = False
 
     def __init__(self, path, queue_name, way='auto', async_num=10):
-        settings = get_project_settings()
+        settings_base = get_project_settings()
+        settings_copy = settings_base.copy()
+        self.settings = dict(overridden_settings(settings_copy))
 
-        self.settings = settings.copy()
-        d = dict(overridden_settings(self.settings))
-        print(d)
         self.path = path
         self.queue_name = queue_name
         self.way = way
@@ -93,7 +87,7 @@ class Engine(object):
         self.channel = None
         self.connector = None
         self.update_machine = None
-        self._settings = settings.__dict__
+        # self._settings = settings.__dict__
 
         self.request = None
         self.loop = None
@@ -102,11 +96,10 @@ class Engine(object):
 
         self.rabbit = None
 
-        self.RANDOM_USER_AGENT = getattr(settings, 'RANDOM_USER_AGENT', False)
+        self.RANDOM_USER_AGENT = self.settings.get('RANDOM_USER_AGENT')
 
-        self.RETRY_ENABLED = getattr(settings, 'RETRY_ENABLED', None)
-        if self.RETRY_ENABLED:
-            self.RETRY_TIMES = getattr(settings, 'RETRY_TIMES', 5)
+        self.RETRY_ENABLED = self.settings.get('RETRY_ENABLED')
+        self.RETRY_TIMES = self.settings.get('RETRY_TIMES')
 
     def get_proxy(self):
         proxy_res = fuclib.getIP()
@@ -121,14 +114,8 @@ class Engine(object):
         self.rabbit = RabbitConnect(scrapy_object=self)
         return self.rabbit.connect()
 
-    def mongo_connection(self):
-        """mongo连接"""
-        self.mongo = MongoDBConnect(self)
-
     def produce(self, url=None, params=None, data=None, json=None, charset=None, cookies=None, method='get',
-                headers=None,
-                callback="parse", allow_redirects=True, meta=None, not_request=None,
-                priority=1):
+                headers=None, callback="parse", allow_redirects=True, meta=None, not_request=None, priority=1):
         """生产"""
         if not isinstance(callback, str):
             callback = callback.__name__
@@ -262,7 +249,7 @@ class Engine(object):
         if self.way == 'auto':
             names = ("error_type", "auto_frequency")
             values = (e.args[0], -1)
-            logger.error("自动更新报错。", names, values)
+            logger.error("采集报错。", names, values)
         os._exit(1)
 
     def callback(self, ch, method, properties, body):
@@ -306,7 +293,7 @@ class Engine(object):
                     self.deal_error(e)
                 self.connector.add_callback_threadsafe(partial(ch.basic_ack, method.delivery_tag))
             else:
-                if self.RETRY_ENABLED:                          # todo
+                if self.RETRY_ENABLED:  # todo 重试方法需要重写
                     retry_times = ret.get('retry_times', 5)
                     if retry_times <= self.RETRY_TIMES:
                         if response:
@@ -338,7 +325,6 @@ class Engine(object):
 
     def before_request(self, ret):
         """请求中间件"""
-
         return ret
 
     @staticmethod
@@ -365,9 +351,9 @@ class Engine(object):
         ]
         for i in serious:
             if hasattr(self, i) and getattr(self, i) is None:
-                attr = getattr(config, i)
+                attr = getattr(conf, i)
                 setattr(self, i, attr if attr else None)
-        self._settings.update(self.custom_settings)
+        self.settings.update(self.custom_settings)
         # self._settings.setdefault('DOWNLOADER_MIDDLEWARES',
         #                           {'DOWNLOADER_MIDDLEWARES': {'frame.tools.middleware.DownloaderMiddleware': 1}})
 
@@ -378,11 +364,12 @@ class Engine(object):
         # # 脚本信息入库
         # self.update_machine = gethostbyname(gethostname())
         # logger.info("本机ip为：%s" % self.update_machine)
+        # todo 保存脚本运行时间
 
         if self.way and (self.way == 'm' or self.way == 'auto'):
             if self.priority_queue:
                 self.channel.queue_declare(queue=self.queue_name, durable=True,
-                                           arguments={"x-max-priority": 10})  # todo 优先级队列切换
+                                           arguments={"x-max-priority": 10})  # todo 优先级队列自动切换
             else:
                 self.channel.queue_declare(queue=self.queue_name, durable=True)
             if self.queue_purge:
