@@ -1,47 +1,51 @@
 # -*- coding: utf-8 -*-
-import sys
-import os
+# Author: Eamonn
+# Email: china.eamonn@gmail.com
+# Link: https://elanpy.com
+
 from importlib import import_module
 import datetime
 import logging
 import time
+import os
+import sys
+from scrapy_rabbit.utils import SpiderLoader
+from scrapy_rabbit.utils import get_project_settings
+from scrapy_rabbit.settings import overridden_settings
 
-import inspect
-from scrapy_rabbit.Lib.loadspider import SpiderLoader
+settings_base = get_project_settings()
+settings_copy = settings_base.copy()
+settings = dict(overridden_settings(settings_copy))
+# log_level = settings.get('LOG_LEVEL', 'ERROR')
+#
+# save_log_file = settings.get('SAVE_LOG', False)
+#
+# if save_log_file:
+#     logging.basicConfig(level=getattr(logging, log_level),
+#                         format='pid:%(process)d %(asctime)s %(filename)s[line:%(lineno)d] %(levelname)s %(message)s',
+#                         datefmt='%Y-%m-%d %H:%M:%S',
+#                         filename=settings.get('LOG_FILE', f'{time.strftime("%Y-%m-%d", time.localtime())}.log'),
+#                         filemode='a'
+#                         )
+# else:
+#     logging.basicConfig(level=getattr(logging, log_level),
+#                         format='pid:%(process)d %(asctime)s %(filename)s[line:%(lineno)d] %(levelname)s %(message)s',
+#                         )  # todo log使用需要修改
 
-sys.path.append(os.path.abspath('.'))
 
-try:
-    sys.path.append(os.path.abspath('../..'))
-    import settings
-except ModuleNotFoundError:
-    sys.path.append(os.path.abspath('..'))
-    import settings
+root = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
+sys.path.append(root)
 
-config = dict()
-
-save_log_file = getattr(settings, 'SAVE_LOG', False)
-if save_log_file:
-    logging.basicConfig(level=getattr(logging, getattr(settings, 'LOG_LEVEL', 'DEBUG')),
-                        format='pid:%(process)d %(asctime)s %(filename)s[line:%(lineno)d] %(levelname)s %(message)s',
-                        datefmt='%Y-%m-%d %H:%M:%S',
-                        filename=getattr(settings, 'LOG_FILE', f'{time.strftime("%Y-%m-%d", time.localtime())}.log'),
-                        # filename=getattr(settings, 'LOG_FILE', f'{time.strftime("%Y-%m-%d", time.localtime())}.log'),
-                        # filename=getattr(logging, getattr(settings, 'LOG_FILE', '')),
-                        # filemode='a'
-                        )
-else:
-    logging.basicConfig(level=getattr(logging, getattr(settings, 'LOG_LEVEL', 'DEBUG')),
-                        format='pid:%(process)d %(asctime)s %(filename)s[line:%(lineno)d] %(levelname)s %(message)s',
-                        datefmt='%Y-%m-%d %H:%M:%S',
-                        # filename=getattr(logging, getattr(settings, 'LOG_FILE', '')),
-                        # filemode='a'
-                        )
+logging.basicConfig(level=getattr(logging, getattr(settings, 'LOG_LEVEL', 'INFO')),
+                    format='pid:%(process)d %(asctime)s %(filename)s[line:%(lineno)d] %(levelname)s %(message)s',
+                    datefmt='%Y-%m-%d %H:%M:%S',
+                    # filename='debug.txt',
+                    # filemode='a'
+                    )
 
 
 def run(cmd) -> None:
     """手动启动方法"""
-
     if isinstance(cmd, str):
         cmd = cmd.split(' ')
     while '' in cmd:
@@ -68,17 +72,6 @@ def run(cmd) -> None:
     spider_module = sl.load(spider_name)
     sp = spider_module(path=path, queue_name=queue_name, way=way, async_num=async_num)
 
-    # frame = __import__(spider_name)
-    # print(spider_module)
-    # print(frame)
-    #
-    # classes = ''
-    # clsmembers = inspect.getmembers(spider_module, inspect.isclass)
-    # for (name, _) in clsmembers:
-    #     print(name, _)
-    #     if 'Spider' in name:
-    #         classes = name
-    # print(classes)
     get_settings = getattr(spider_module, 'custom_settings', None)
 
     # a = {
@@ -89,6 +82,7 @@ def run(cmd) -> None:
     # }
     #
     # print(sorted(a.items(), key=lambda item: item[1]))
+    # todo 多个pipline按顺序执行
 
     if get_settings:
         try:
